mriqc.workflows package — mriqc 0.1.0 documentation

# mriqc.workflows package

## Submodules

## mriqc.workflows.anatomical module

A QC workflow for anatomical MRI

`mriqc.workflows.anatomical.` `anat_qc_workflow`(name='aMRIQC', settings=None, sub_list=None)

  The anatomical quality control workflow

`mriqc.workflows.anatomical.` `brainmsk_wf`(name='BrainMaskWorkflow')

  Computes a brain mask from the original T1 and the skull-stripped

`mriqc.workflows.anatomical.` `mri_reorient_wf`(name='ReorientWorkflow')

  A workflow to reorient images to ‘RPI’ orientation

`mriqc.workflows.anatomical.` `skullstrip_wf`(name='SkullStripWorkflow')

  Skull-stripping workflow

`mriqc.workflows.anatomical.` `slice_head_mask`(in_file, in_coords, out_file=None)

## mriqc.workflows.core module

The core module combines the existing workflows

`mriqc.workflows.core.` `qc_workflows`(settings=None, subjects=None)

  The CRN quality control workflows

## mriqc.workflows.functional module

A QC workflow for fMRI data

`mriqc.workflows.functional.` `fmri_bmsk_workflow`(name='fMRIBrainMask', use_bet=False)

  Comute brain mask of an fmri dataset

`mriqc.workflows.functional.` `fmri_hmc_workflow`(name='fMRI_HMC', st_correct=False)

  A head motion correction (HMC) workflow for functional scans

`mriqc.workflows.functional.` `fmri_qc_workflow`(name='fMRIQC', sub_list=None, settings=None)

  The fMRI qc workflow

## mriqc.workflows.utils module

`mriqc.workflows.utils.` `fmri_getidx`(in_file, start_idx, stop_idx)

## Module contents